# Generated by Django 4.2.6 on 2023-12-01 17:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nvc_dhl_tracker", "0002_dhlpackage_dhlapikey_exhausted"),
    ]

    operations = [
        migrations.AddField(
            model_name="dhlpackage",
            name="origin",
            field=models.CharField(default="", max_length=1024),
            preserve_default=False,
        ),
    ]
