# Generated by Django 4.2.6 on 2023-12-01 17:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nvc_dhl_tracker", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="DhlPackage",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("number", models.CharField(max_length=1024)),
                ("discovered", models.DateTimeField()),
                ("location", models.CharField(max_length=1024)),
                ("current_status", models.CharField(max_length=512)),
                ("became_pre_transit", models.DateTimeField()),
                ("became_transit", models.DateTimeField()),
                ("became_delivered", models.DateTimeField()),
            ],
        ),
        migrations.AddField(
            model_name="dhlapikey",
            name="exhausted",
            field=models.BooleanField(default=False),
        ),
    ]
