# Generated by Django 4.2.6 on 2023-12-01 17:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nvc_dhl_tracker", "0003_dhlpackage_origin"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dhlpackage",
            name="discovered",
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]
